package d1.core;

import java.io.PrintStream;

/**
 * Diagnostics entry point.
 */
public class Diagnostics {

    public static final int MIN_ALLOWED_MEMORY=32;

    /**
     * public entry point
     * @param args
     */
    public static void main(String args[]) {
        Diagnostics diag=new Diagnostics();
        if(!diag.diagnose(System.out)) {
            System.exit(-1);
        }

    }

    /**
     * check for a class existing. We do not try to load it, so
     * dependencies are not checked
     * @param classname name of the class
     * @return true iff there is a class of that name on the classpath
     */
    public boolean hasClass(String classname) {
        try {
            Class.forName(classname);
        } catch (ClassNotFoundException e) {
            return false;
        }
        return true;
    }

    /**
     * look at our health and diagnose problems
     * @param out
     * @return true if we are happy
     */
    private boolean diagnose(PrintStream out) {

        out.println(System.getProperty("java.class.path"));

        long maxMem=Runtime.getRuntime().maxMemory()/(1024*1024L);
        if(maxMem<MIN_ALLOWED_MEMORY) {
            out.println("Need at least "+MIN_ALLOWED_MEMORY+" MB of memory"
                +" but we only have "+maxMem);
            return false;
        }
        return true;
    }

}
