package d1.core.test;

import d1.core.Event;

import java.util.Date;
import java.util.UUID;

/**
 * Test the event class
 */
public class EventTest extends CoreTestCase {

    public EventTest(String s) {
        super(s);
    }

    public void testSelfEqual() throws Exception {
        Event spring = createSpringEquinox(newID());
        assertComparableObjectsEqual(spring, spring);
    }

    public void testEquality() throws Exception {
        UUID id=newID();
        Event spring = createSpringEquinox(id);
        Event spring_sameID = createSpringEquinox(id);
        assertComparableObjectsEqual(spring, spring_sameID);
    }

    /**
     * test that the hashcode is only derived from the id, by
     * changing everything else and verifying it is constant
     */
    public void testHashCodeConstant() {
        Event spring = createSpringEquinox(newID());
        int hash1 = spring.hashCode();
        spring.setName("Mayday");
        spring.setText("First of may");
        spring.setDate(new Date(YEAR, 5, 1));
        int hash2 = spring.hashCode();
        assertEquals(hash1, hash2);

    }

    public void testEqualityFailure() throws Exception {
        Event spring = createSpringEquinox(newID());
        Event spring_new_ID = createSpringEquinox(newID());
        assertTrue("Expected "+spring+" to not equal "+spring_new_ID,
                !spring.equals(spring_new_ID));
    }


    /**
     * try a null event
     *
     * @throws Exception
     */
    public void testNullNotEqual() throws Exception {
        Event spring = createSpringEquinox(newID());
        Event nullEvent = new Event();
        assertFalse(spring.equals(nullEvent));
    }

    /**
     * compare two different things with only matching ID
     */
    public void testEqualsByIdOnly() {
        UUID id = newID();
        Event spring = createSpringEquinox(id);
        Event autumn = createAutumnEquinox(id);
        assertEquals(spring, autumn);
    }

    public void testValid() throws Exception {
        Event event = new Event(newID(),
                new Date(YEAR, 12, 31),
                "Hogmanay",
                "New Year's Eve");
        assertValid(event);
    }

    public void testIDNeeded() throws Exception {
        Event event = createSpringEquinox(null);
        assertInvalid(event, Event.ERROR_NO_ID);
    }

    public void testDateNeeded() throws Exception {
        Event event = new Event(UUID.randomUUID(),
                null,
                "Event",
                null);
        assertInvalid(event, Event.ERROR_NO_DATE);
    }

    public void testNameNeeded() throws Exception {
        Event event = createSpringEquinox(newID());
        event.setName(null);
        assertInvalid(event, Event.ERROR_NO_NAME);
    }

    public void testTextNotNeeded() throws Exception {
        Event event = createSpringEquinox(newID());
        event.setText(null);
        assertValid(event);
    }


}
