package d1.core.test;

import d1.core.Event;
import d1.core.Events;

import java.io.File;
import java.io.FileNotFoundException;

/**
 * Test event sets
 */
public class EventsTest extends CoreTestCase {

    public EventsTest(String s) {
        super(s);
    }

    public void testCalendarFillsUp() throws Exception {
        Events calendar = createCalendar();
        assertTrue(calendar.size() > 2);
    }

    public void testCalendarValid() {
        Events calendar = createCalendar();
        assertValid(calendar);
    }

    public void testTestInvalidCalendar() throws Exception {
        Events calendar = createCalendar();
        Event nullEvent = new Event();
        calendar.add(nullEvent);
        assertInvalid(calendar, Event.ERROR_NO_ID);
    }


    public void testCalendarSaveAndLoad() throws Exception {
        Events calendar = createCalendar();
        File tempfile = File.createTempFile("cal", ".cal");
        boolean debug = Boolean.getBoolean("debug");
        try {
            calendar.save(tempfile.getAbsolutePath());
            Events loaded = Events.load(tempfile.getAbsolutePath());
            assertValid(loaded);
            assertEquals("size mismatch on loaded calendar",
                    loaded.size(), calendar.size());
            //iterate through all loaded events, assert they are in the
            //original
            for (Event loadedEvent : loaded) {
                Event original = calendar.lookup(loadedEvent.getId());
                assertNotSame("loaded events should be new instances",
                        original, loaded);
                //our error message
                String message = "Not Equal: " + original + " and " + loadedEvent;
                assertEquals(message, original, loadedEvent);
                assertEquals(message,
                        original.getDate(),
                        loadedEvent.getDate());
                assertEquals(message,
                        original.getName(),
                        loadedEvent.getName());
                assertEquals(message,
                        original.getText(),
                        loadedEvent.getText());
            }
        } finally {
            if (!debug) {
                //save files in debug mode, it gives us a binary file to
                //play with
                tempfile.delete();
            }
        }

    }


    public void testLoadMissingFile() throws Exception {
        try {
            Events loaded = Events.load("a-file-that-doesnt-exist");
            fail("We expected to fail here");
        } catch (FileNotFoundException e) {
            //success
        }
    }

    public void NotestLoadCorruptFile() throws Exception {
        File dir = getFileProperty("data.dir");
    }

    public void testCreation() throws Exception {
        Events calendar = createCalendar();
        Event evt1=calendar.createEvent();

        assertNotNull(evt1.getId());
        assertTrue(calendar.lookup(evt1.getId())!=null);
        Event evt2 = calendar.createEvent();
        evt2.setName("2");
        assertNotNull(evt2.getId());
        assertTrue("created events are different2",!evt2.equals(evt1));

    }
}
