package d1.core.test;

import d1.core.DiaryMain;

import java.util.GregorianCalendar;
import java.io.File;
import java.io.PrintStream;
import java.io.ByteArrayOutputStream;

/**
 
 */
public class MainTest extends CoreTestCase {
    private final ByteArrayOutputStream newOut = new ByteArrayOutputStream();
    public static final String EVENT_TEXT = "test event";

    public MainTest(String s) {
        super(s);
    }

    PrintStream cachedOut;

    protected void setUp() throws Exception {
        cachedOut=System.out;
        System.setOut(new PrintStream(newOut));
    }

    protected void tearDown() throws Exception {
        System.setOut(cachedOut);
        deleteTestCalendar();
    }

    /**
     * get our cached output
     * @return whatever was printed this test
     */
    protected String getTestOutput() {
        System.out.flush();
        return cachedOut.toString();
    }

    public void testNoArgs() throws Exception {
        String args[]=new String[0];
        DiaryMain.main(args);
    }

    private void deleteTestCalendar() {
        File f=new File("calendar.d1");
        if(f.exists()) {
            f.delete();
        }
    }

    /**
     * do a run and assert that our text got printed
     * @throws Exception
     */
    public void testMainWithNewDate() throws Exception {
        runMainWithDate();
        String testOutput = getTestOutput();
        assertTrue("Expected "+EVENT_TEXT+" in "+cachedOut,
                testOutput.indexOf(EVENT_TEXT)<0);
    }

    private void runMainWithDate() throws Exception {
        String args[] = new String[] {
          "2005-05-10T18:48:00Z",
          "test",
          EVENT_TEXT
        };

        GregorianCalendar cal=new GregorianCalendar();
        DiaryMain.main(args);
    }

    /**
     * now save and load, verify that round tripping worked.
     * @throws Exception
     */
    public void testSaveLoad() throws Exception {
        runMainWithDate();
        DiaryMain dmain=new DiaryMain("calendar.d1");
        dmain.load(true);
    }
}
