package d1.core.test;

import junit.framework.AssertionFailedError;

import java.io.File;

/**
 * Test property passdown
 */
public class PropertyTest extends CoreTestCase {

    public PropertyTest(String s) {
        super(s);
    }

    public void testProperties() throws Exception {
        String url = System.getProperty("test.url");
        String dataDir = System.getProperty("data.dir");
        boolean debug = Boolean.getBoolean("debug");
    }

    public void testProperty() throws Exception {
        System.setProperty("test.url", "http://localhost/");
        String url = getProperty("test.url");
    }

    public void testGoodDirectory() throws Exception {
        File temp = getFileProperty("java.io.tmpdir");
    }

    public void testNonexistantDirectory() throws Exception {
        final String key = "java.vm.vendor";
        System.getProperty(key);
        try {
            File badDir = getFileProperty(key);
            fail("should have got a bad dir");
        } catch (AssertionFailedError e) {
            //success
        }
    }

    public void testBooleanTrue() throws Exception {
        System.setProperty("bool", "true");
        boolean debug = getBooleanProperty("bool");
        assertTrue(debug);
    }

    public void testBooleanTRUE() throws Exception {
        System.setProperty("bool", "TRUE");
        boolean debug = getBooleanProperty("bool");
        assertTrue(debug);
    }

    public void testBooleanFalse() throws Exception {
        System.setProperty("bool", "false-is-not-true");
        boolean debug = getBooleanProperty("bool");
        assertFalse(debug);
    }

    public void testInteger() throws Exception {
        System.setProperty("int", "5");
        int value = getIntProperty("int");
        assertEquals(5, value);
    }

    public void testBadInteger() {
        System.setProperty("int", "not an integer");
        int value = 0;
        try {
            value = getIntProperty("int");
            fail("should not have got here");
        } catch (NumberFormatException e) {
            //succeed

        }
    }
}
