package d1.persist.test.hibernate;

import org.hibernate.cfg.Environment;
import org.hibernate.SessionFactory;
import d1.persist.hibernate.HibernateTools;
import d1.persist.PersistTools;

import javax.persistence.EntityManagerFactory;
import javax.persistence.EntityManager;
import java.util.Properties;

/**
 */
public class HibernateToolsTest extends HibernateTestBase {


    public HibernateToolsTest(String s) {
        super(s);
    }

    /**
     * Test creation of the driver. Isolates this step from the rest
     * of the system, and checks that setUp() configured the settings field.
     * @throws Exception
     */
    public void testDriverPresent() throws Exception {
        Class.forName(settings.getProperty(Environment.DRIVER)).newInstance();
    }

    /**
     * Test that the factory can be created, and that
     * it returns the same (non-null) instance every time.
     * @throws Exception
     */
    public void testSessionFactory() throws Exception {

        SessionFactory factory = HibernateTools.getSessionFactory();
        assertNotNull(factory);

        SessionFactory factory2 = HibernateTools.getSessionFactory();

        assertSame(factory,factory2);

    }

    /**
     * Create the session manager
     * @throws Exception
     */
    public void testResourceFactoryHSQLDB() throws Exception {
        SessionFactory factory = null;
        try {
            factory = HibernateTools.createSessionFactory(
                    HibernateTools.HIBERNATE_HSQLDB_RESOURCE,
                    null);
            assertNotNull(factory);
        } finally {
            if (factory != null) {
                factory.close();
            }
        }
    }

    public void testEntityManagerFactory() throws Exception {
        EntityManagerFactory factory;
        factory = PersistTools.createEntityManagerFactory(settings);
        assertNotNull(factory);
        try {
            EntityManager manager = factory.createEntityManager();
            manager.close();
        } finally {
            factory.close();
        }
    }


public static Properties createSettings() {
    Properties props = new Properties();
    props.put("hibernate.connection.driver_class",
            "org.hsqldb.jdbcDriver");
    props.put("hibernate.connection.url", "jdbc:hsqldb:mem:.");
    props.put("hibernate.hbm2ddl.auto", "create-drop");
    return props;
}
    /**
     * test the entity manager
     * @throws Exception
     */
public void testEntityManagerFactoryInline() throws Exception {
    Properties props = HibernateToolsTest.createSettings();
    EntityManagerFactory factory;
    factory = PersistTools.createEntityManagerFactory(props);
    assertNotNull(factory);
    try {
        EntityManager manager = factory.createEntityManager();
        manager.close();
    } finally {
        factory.close();
    }
}


    /**
     * Needs a mysql driver
     * @throws Exception
     */
    public void NotestResourceFactoryMySql() throws Exception {
        SessionFactory factory = null;
        try {
            factory = HibernateTools.createSessionFactory(
                    HibernateTools.HIBERNATE_MYSQL_RESOURCE,
                    null);
            assertNotNull(factory);
        } finally {
            if (factory != null) {
                factory.close();
            }
        }
    }
}
