package d1.webapp;

import d1.persist.session.CalendarCreator;

import javax.naming.Context;
import javax.naming.InitialContext;
import javax.naming.NamingException;
import javax.naming.NamingEnumeration;
import javax.naming.NameClassPair;
import java.net.URL;
import java.util.ArrayList;
import java.util.List;

/** find a class */
public class FindClass {


    private FindClass() {
    }

    public static String locate(String classname) {
        return locate(classname, "failed to load " + classname);
    }

    public static String locate(String classname, String text) {
        try {
            Class type = Class.forName(classname);
            URL url = type.getProtectionDomain()
                .getCodeSource()
                .getLocation();
            return type.toString() + " from " + url.toString();
        } catch (Throwable e) {
            throw new RuntimeException(text, e);
        }
    }


    /**
     * Look for an ldap entry
     *
     * @param path      path on the server
     * @return the string value of whatever was looked up
     */
    public static String ldapLookup(String path) {
        return ldapLookup(path,null);
    }
    /**
     * Look for an ldap entry
     * @param path path on the server
     * @param classname classname expected
     * @return the string value of whatever was looked up
     */
    public static String ldapLookup(String path,String classname) {
        Context context=null;
        try {
            context = new InitialContext();
            Object result = context.lookup(path);
            if(result==null) {
                return path + ":=null";
            }
            Class type = result.getClass();
            if (classname != null &&
                !classname.equals(type.getSimpleName())) {
                throw new RuntimeException("Object on path " + path + '\n'
                    + "was expected to be of type " + classname + '\n'
                    + "but is of type " + type.getSimpleName());
            }
            return path+":="+result.toString();
        } catch (NamingException e) {
            throw new RuntimeException(
                "Naming excepion:"
                    + path + " - " + e.toString());
        } finally {
            close(context);
        }
    }

    private static void close(Context context) {
        if(context!=null) {
            try {
                context.close();
            } catch (NamingException ignore) {
                //ignore
            }
        }
    }


    /**
     * Extract everything under a path as an iterator.
     * @param path path to search under
     * @return an iterator over the bindings
     * @throws RuntimeException if nothing was found
     */
    public static List<NameClassPair> list(String path) {
        ArrayList<NameClassPair> names=new ArrayList<NameClassPair>();
        NamingEnumeration<NameClassPair> result=null;
        Context context = null;
        try {
            context = new InitialContext();
            result = context.list(path);
            while (result.hasMoreElements()) {
                NameClassPair pair =  result.nextElement();
                names.add(pair);
            }
            return names;
        } catch (NamingException e) {
            throw new RuntimeException(
                "Naming excepion:"
                    + path + " - " + e.toString());
        } finally {
            close(result);
            close(context);
        }
    }

    private static void close(NamingEnumeration<NameClassPair> result) {
        try {
            if(result!=null) {
                result.close();
            }
        } catch (NamingException ignore) {
            //ignore
        }
    }

    /**
     * Return information about the factory
     * @return the toString() value of the current factory.
     */
    public static String getFactoryInfo() {
        return CalendarCreator.getFactory().toString();
    }

}
