package d1.webapp.config;

import d1.persist.session.CalendarCreator;
import d1.persist.session.CalendarFactory;
import d1.persist.session.CalendarHelper;
import d1.persist.session.CalendarSession;
import d1.persist.session.JavaEECalendarFactory;
import d1.persist.session.JBoss4CalendarFactory;

import java.util.Properties;
import java.util.logging.Logger;


/**
 */
public final class CalendarBinding {

    private static final Logger logger= Logger.getLogger(CalendarBinding.class.toString());


    /** prefix for all bindings {@value} */
    public static final String BINDING_PREFIX = "db.";

    /**
     * Property that indicates we are dynamic; should be preceeded by the
     * binding prefix {@value}
     */
    public static final String PROP_DYNAMIC = "dynamic";

    /**
     * flag to indicate that we dont want to bind to the database. This is
     * actually something you may want to consider when EJB is misbehaving
     * {@value}
     */
    public static final String PROP_NO_BINDING = "offline";

    /**
     * best place to look on JBoss 4
     * {@value}
     */
    public static final String DIARY_CALENDAR_SESSION_BEAN_LOCAL =
        "diary/CalendarSessionBean/local";

    /**
     * another place to look on JBoss 4
     * {@value}
     */
    public static final String D1_PERSIST_CALENDAR_SESSION =
        "d1.persist.session.CalendarSession";

    /** The JNDI name of the diary. Keep in sync w/ persistence.xml {@value} */
    public static final String CALENDAR_SESSION_BEAN_JNDI_PATH =
        D1_PERSIST_CALENDAR_SESSION;

    private CalendarBinding() {
    }

    /**
     * Do the calendar setup here
     *
     * @param props property options
     * @return a configured calendar
     */
    public static boolean configureCalendar(Properties props) {
        CalendarFactory calendarFactory;

        if (props.getProperty(PROP_NO_BINDING) != null) {
            return false;
        }
        try {
            calendarFactory = new JavaEECalendarFactory();
            CalendarSession session;
            //fall back to jboss 4.x when injection fails
            try {
                session = bindAndQuery(calendarFactory);
            } catch (Throwable e) {
                logger.throwing("CalendarBinding", "configureCalendar",e);
                //switch to jboss
                try {
                    session = bindAndQuery(new JBoss4CalendarFactory(
                        CALENDAR_SESSION_BEAN_JNDI_PATH));
                } catch (Throwable e1) {
                    //try another path
                    session = bindAndQuery(new JBoss4CalendarFactory(
                        DIARY_CALENDAR_SESSION_BEAN_LOCAL));
                }
            }
            if (session.getEventCount("") == 0) {
                //populate the db
                CalendarHelper helper = new CalendarHelper(session);
                helper.populateEvents();
            }
            return true;
        } catch (Throwable e) {
            //we bail out here 
            logger.throwing("CalendarBinding","configureCalendar",e);
            return false;
        }
    }

    private static CalendarSession bindAndQuery(CalendarFactory calendarFactory) {
        CalendarSession session;
        CalendarCreator.setFactory(calendarFactory);
        session = CalendarCreator.getSession();
        return session;
    }
}
