package d1.webapp.servlets;

import d1.persist.Event;
import d1.persist.session.CalendarCreator;
import d1.persist.session.CalendarSession;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.PrintWriter;

/**
 * @web.servlet name="SingleEvent" display-name="SingleEvent"
 * @web.servlet-mapping url-pattern="/event"
 */
public class SingleEventServlet extends HttpServlet {
    public static final String PARAM_ID = "id";

    protected void doGet(HttpServletRequest request,
                         HttpServletResponse response)
            throws ServletException, IOException {
        String id = request.getParameter(PARAM_ID);
        Event event = null;
        if (id == null) {
            returnHttpPage(response,200, "event",
                    "Set an id parameter to look up an event");
        } else {
            CalendarSession session = CalendarCreator.getSession();
            event = session.findEvent(id);
            if (event != null) {
                returnHttpPage(response,
                    200,
                    event.getName(),
                    event.getText());
            } else {
                returnHttpPage(response, 404,
                    "event",
                    "Unknown Event ID");
            }
        }
    }

    /**
     * Return a simple HTML page with the title and text supplied
     * @param response
     * @param title
     * @param text
     * @throws IOException
     */
    private void returnHttpPage(HttpServletResponse response, int status, String title,
                                String text) throws IOException {
        response.setStatus(status);
        PrintWriter out = response.getWriter();
        out.println("<html><head><title>");
        out.println(title);
        out.println("</title></head>");
        out.println("<body>");
        out.println(text);
        out.println("</body></html>");
    }
}
