package d1.webapp.test;

import com.meterware.httpunit.GetMethodWebRequest;
import com.meterware.httpunit.HttpUnitOptions;
import com.meterware.httpunit.WebConversation;
import com.meterware.httpunit.WebRequest;
import com.meterware.httpunit.WebResponse;
import com.meterware.httpunit.parsing.HTMLParserFactory;
import junit.framework.TestCase;
import org.xml.sax.SAXException;

import java.io.IOException;

/**
 * This is the base class for all out tests. It contains a private cache of the
 * server.url property passed to the JVM, and creates a new WebConversation
 * every test run. Helper methods exist to retrieve pages
 */
public abstract class WebTestBase extends TestCase {
    protected String url;
    protected WebConversation session;

    public WebTestBase(String name) {
        super(name);
    }

    public void setUp() throws Exception {
        super.setUp();
        url = System.getProperty("server.url");
        assertNotNull("server.url not set", url);
        HTMLParserFactory.setPreserveTagCase(false);
        HttpUnitOptions.setExceptionsThrownOnErrorStatus(true);
        HttpUnitOptions.setMatchesIgnoreCase(true);
        session = new WebConversation();
    }

    protected GetMethodWebRequest requestPage(String page) {
        return new GetMethodWebRequest(url + page);
    }

    protected WebResponse getPage(String page)
        throws IOException, SAXException {
        WebRequest request = requestPage(page);
        return session.getResponse(request);
    }

    protected WebResponse getHomePage() throws IOException, SAXException {
        return getPage("");
    }

}
