package d1.webapp.test.cactus;

import d1.persist.Event;
import d1.persist.session.CalendarCreator;
import d1.persist.session.CalendarSession;
import org.apache.cactus.ServletTestCase;

import java.util.Date;

/**
 * This uses Cactus to test the application. These tests are designed to run in
 * the server
 */
public class CactusPersistTest extends ServletTestCase {
    private static int counter = 0;
    private CalendarSession calendar;

    public CactusPersistTest(String string) {
        super(string);
    }

    /**
     * Sets up the fixture, for example, open a network connection. This method
     * is called before a test is executed.
     */
    protected void setUp() throws Exception {
        super.setUp();
        calendar = CalendarCreator.getSession();
        assertNotNull(calendar);
    }

    /**
     * Tears down the fixture, for example, close a network connection. This
     * method is called after a test is executed.
     */
    protected void tearDown() throws Exception {
        super.tearDown();
    }

    protected Event createTestEvent() {
        counter++;
        Event event = new Event();
        event.newId();
        Date date = new Date();
        event.setDate(date);
        event.setLastModified(date);
        event.setName("Event #" + counter);
        event.setText("test event #" + counter + " created at " + date);
        return event;
    }

    public void testPersistAndRetrieve() throws Exception {

        Event event = createTestEvent();
        calendar.addOrUpdate(event);
        assertEventIsInDB(event);
    }

    public void testDelete() throws Exception {
        Event event = createTestEvent();
        calendar.addOrUpdate(event);
        assertEventIsInDB(event);
        calendar.removeEvent(event.getKey());
        assertEventIsntInDB(event);
    }

    private void assertEventIsInDB(Event event) {
        Event loaded = calendar.findEvent(event.getKey());
        assertTrue("Cound not find event "+event.toString(),loaded!=null);
        assertEquals(event, loaded);
    }

    private void assertEventIsntInDB(Event event) {
        Event loaded = calendar.findEvent(event.getKey());
        assertFalse("Expected not to find event " + event.toString(), loaded != null);
    }




}
