package d1.webapp.test.cactus;

import d1.persist.Event;
import d1.persist.session.CalendarCreator;
import d1.persist.session.CalendarSession;
import org.apache.cactus.ServletTestCase;

import java.util.Date;
import java.util.List;
import java.util.UUID;

/**
 * Set of low level unit test to look at bits of the model behind the web page
 */
public class Calendar2Test extends ServletTestCase {
    private CalendarSession calendar;

    public Calendar2Test(String string) {
        super(string);
    }

    /**
     * Sets up the fixture, for example, open a network connection. This method
     * is called before a test is executed.
     */
    protected void setUp() throws Exception {
        super.setUp();
        calendar = CalendarCreator.getSession();
    }

    public void testNotNull() throws Exception {
        assertNotNull(calendar);
    }

    public void testHasEvents() throws Exception {
        List<Event> events = calendar.getEvents();
        assertTrue(!events.isEmpty());
        assertEquals(events.size(), calendar.getEventCount(""));
    }

    public void testSelectByKey() throws Exception {
        List<Event> events = calendar.getEvents();
        Event event = events.get(0);
        Event e2 = calendar.findEvent(event.getKey());
        assertEquals(event, e2);
    }

    public void testSelectByQuery() throws Exception {
        List<Event> events = calendar.getEvents();
        Event event = events.get(0);
        String query = "event.name='" + event.getName() + "'";
        int count = calendar.getEventCount(query);
        List<Event> match = calendar.getEvents(query);
        assertTrue(!match.isEmpty());
        assertEquals(count,match.size());
        Event e2 = match.get(0);
        assertEquals(event, e2);
    }

    public void testAddAndRemove2() throws Exception {
        Event e = new Event(UUID.randomUUID(),
                new Date(),
                "test",
                "test adding");

        calendar.addOrUpdate(e);
        Event found1 = calendar.findEvent(e.getKey());
        Event found2 = calendar.findEvent(e.getId());
        assertEquals(e, found1);
        assertEquals(e, found2);
        calendar.removeEvent(e.getKey());
        assertNull(calendar.findEvent(e.getId()));
    }

    public void testRemove() throws Throwable {
        List<Event> events = calendar.getEvents();
        Event event = events.get(0);
        String key = event.getKey();
        calendar.removeEvent(key);
        Event e2 = calendar.findEvent(key);
        assertNull(e2);
    }

}
