package d1.webapp.test.cactus;

import org.apache.cactus.ServletTestCase;
import d1.webapp.FindClass;

/**
 * This tests the FindClass class we use in servlet examples.
 * What, you think we'd ship something without unit tests? no no no.
 *
 * Remember that Cactus classes get instantiated on both the client
 * and the server. Its critical not to use any classes that the client
 * doesnt have, like the servlet API, EJB stuff, etc. You can use interfaces
 * and reflection, but not anything in the constructor/setup that requires linking
 * to classes that wont be there.
 *
 * This is a key limitation of cactus, and why we need something better, eventually.
 *
 */

public class FindClassTest extends ServletTestCase {


    public FindClassTest(String string) {
        super(string);
    }

    /**
     * Test that a missing class throws an exception with no name
     * @throws Exception
     */
    public void testMissingClass() throws Exception {
        try {
            FindClass.locate("nonexistent.class");
        } catch (RuntimeException e) {
            assertTrue(e.getMessage().startsWith("failed to load"));
            assertTrue(e.getMessage().contains("nonexistent.class"));
        }
    }

    /**
     * Test that we can set the message
     * @throws Exception
     */
    public void testMissingClassMessage() throws Exception {
        try {
            FindClass.locate("nonexistent.class", "no-such-class");
        } catch (RuntimeException e) {
            assertEquals("no-such-class", e.getMessage());
        }
    }

    public void testFindSelf() throws Exception {
        FindClass.locate(getClass().getName());
    }

    public void testFindLog4J() throws Exception {
        FindClass.locate("org.apache.log4j.PatternLayout");
    }


    public void testFindJDOM() throws Exception {
        FindClass.locate("org.jdom.JDOMException");
    }

    /**
     * Head over the alps to Milano, Torino or Bolzano/Bozen, keep going south :)
     * @throws Exception
     */
    public void testFindRome() throws Exception {
        FindClass.locate("com.sun.syndication.io.FeedException");
    }

    public void testFindWebapp() throws Exception {
        FindClass.locate("d1.webapp.servlets.LifecycleListener");
    }

    public void testFindCalendarFactory() throws Exception {
        FindClass.locate("d1.persist.session.CalendarFactory");
    }

    public void testFindCoreEvent() throws Exception {
        FindClass.locate("d1.core.Event");
    }

    public void testFindPersistEvent() throws Exception {
        FindClass.locate("d1.persist.Event");
    }

}
