package d1.persist;

import javax.persistence.EntityManagerFactory;
import javax.persistence.EntityTransaction;
import javax.persistence.Persistence;
import java.util.Enumeration;
import java.util.Map;
import java.util.Properties;

/**
 * Hibernate support classes, including EJB3 stuff.
 */
public final class PersistTools {
    /**
     * The name of the default persistence context.
     * {@value}
     */
    public static final String DEFAULT_PERSISTENCE_CONTEXT = "diary";

    private PersistTools() {
    }

    /**
     * Creates an entity manager with the compile-time default name, as
     * derived from {@link #DEFAULT_PERSISTENCE_CONTEXT}
     * @return a new entity manager
     */
    public static EntityManagerFactory
            createEntityManagerFactory(Map options) {
        EntityManagerFactory factory;
        factory = Persistence.createEntityManagerFactory(DEFAULT_PERSISTENCE_CONTEXT,options);
        return factory;
    }

    /**
     * Create an entity manager
     * @param manager name of the manager to retrieve from the
     * persistence.xml
     * @param options any other options
     * @return an EntityManagerFactory implementation
     */
    public static EntityManagerFactory
            createManagerFactory(String manager, Map options) {
        EntityManagerFactory factory;
        factory = Persistence.createEntityManagerFactory(manager,options);
        return factory;
    }

    /**
     * extract all properties from source with the given prefix, strip the prefix
     * and return a new Properties instance with the values bound to the stripped
     * keys
     * @param source source properties
     * @param prefix prefix to match for and strip
     * @return the set of matching and stripped properties 
     *  (may be size 0, but never null)
     */
    public static Properties extractOptionsWithPrefix(Properties source,String prefix) {
        Properties result=new Properties();
        Enumeration keys=source.propertyNames();
        while (keys.hasMoreElements()) {
            String key = (String) keys.nextElement();
            if(key.startsWith(prefix)) {
                String tail=key.substring(prefix.length());
                result.setProperty(tail, source.getProperty(key));
            }
        }
        return result;
    }

    /**
     * Roll back a transaction
     * @param tx
     */
    public static void rollback(EntityTransaction tx) {
        if (tx != null && tx.isActive()) {
            tx.rollback();
        }
    }
}
