package d1.persist.session;

/** Static class to hold the factory singleton */
public class CalendarCreator {

    /**
     * static null factory used whenenver the factory is decommissioned
     */
    private static UnconfiguredFactory nullFactory = new UnconfiguredFactory();

    /**
     * The real factory
     */
    private static CalendarFactory factory = nullFactory;

    private CalendarCreator() {
    }

    public static synchronized CalendarFactory getFactory() {
        return factory;
    }

    public static synchronized void setFactory(CalendarFactory newfactory) {
        close();
        factory = newfactory;
    }

    /**
     * Get a session from a factory
     *
     * @return the session returned by the factory
     */
    public static synchronized CalendarSession getSession() {
        CalendarSession session = getFactory().getSession();
        if (session == null) {
            throw new IllegalStateException(
                " Calendar Factory " +
                    factory +
                    " is returning null sessions.\n"
                    +
                    factory.getLikelyCauseOfFailure());
        }
        return session;
    }

    /** at terminate time the session factory is closed */
    public static synchronized void close() {
        try {
            getFactory().closeFactory();
        } finally {
            factory = nullFactory;
        }
    }
}
