package d1.persist.session;

import d1.persist.Event;

import java.util.List;
import java.util.UUID;


public interface CalendarSession {

    /**
     * add a new event or update an existing one
     *
     * @param event event to add or update
     */
    void addOrUpdate(Event event);

    /**
     * Look up an event by key.
     *
     * @param key ID of event
     * @return event or null for no match
     */
    Event findEvent(String key);

    /**
     * Find a new event
     *
     * @param id
     * @return
     */
    Event findEvent(UUID id);


    /**
     * Get the number of events in the database matching a query
     *
     * @param where query string
     *
     * @return the current event count
     */
    int getEventCount(String where);

    /**
     * Get the number of events in the database
     *
     * @return the current event count
     */
    int getEventCount();

    /**
     * Get all events in the database
     *
     * @return all events
     */
    List<Event> getEvents();

    /**
     * Get the events that match a criteria.
     *
     * @param where search string or null for all events
     * @return a list of all events matching the pattern
     */
    List<Event> getEvents(String where);


    /**
     * Remove an event given by a key
     * Do nothing if it is not present.
     * @param key
     * @return true if it was present and removed
     */
    boolean removeEvent(String key);
}
