package d1.persist.session;

import d1.persist.Event;

import javax.ejb.*;
import javax.persistence.*;
import java.util.List;
import java.util.UUID;

/**
 * This is the calendar session bean
 */
@Stateless
@Local(CalendarSession.class)

public class CalendarSessionBean implements CalendarSession {


    @PersistenceContext
    public EntityManager manager;

    public CalendarSessionBean() {
    }

    /**
     * add a new event or update an existing one
     *
     * @param event event to add or update
     */
    public void addOrUpdate(Event event) {
        manager.persist(event);
    }
    /**
     * Look up an event by key.
     *
     * @param key ID of event
     * @return event or null for no match
     */
    public Event findEvent(String key) {
        Event loaded = manager.find(Event.class, key);
        return loaded;
    }


    /**
     * Get the number of events in the database
     *
     * @param where query string
     * @return the current event count
     */
    public int getEventCount(String where) {
        String queryString = "SELECT COUNT(event) FROM Event event";
        if (where != null && where.length() > 0) {
            queryString += " WHERE " + where;
        }
        Query query = manager.createQuery(queryString);
        Object result = query.getSingleResult();
        return ((Long) result).intValue();
    }


    /**
     * Get the number of events in the database
     *
     * @return the current event count
     */
    public int getEventCount() {
        return getEventCount(null);
    }

    /**
     * Get the events that match a criteria.
     *
     * @param where search string or null for all events
     *
     * @return a list of all events matching the pattern
     */
    public List<Event> getEvents(String where) {
        String queryString = makeSelection(where);
        Query query = manager.createQuery(
                queryString);
        return (List<Event>) query.getResultList();
    }


    /**
     * Remove an event given by a key Do nothing if it is not present.
     *
     * @param key
     *
     * @return true if it was present and removed
     */
    public boolean removeEvent(String key) {
        Event loaded = manager.find(Event.class, key);
        if (loaded != null) {
            manager.remove(loaded);
            return true;
        }
        return false;
    }


    /**
     * Find a new event
     *
     * @param id
     * @return the event
     */
    public Event findEvent(UUID id) {
        return findEvent(id.toString());
    }

    /**
     * Get all events in the database
     *
     * @return all events
     */
    public List<Event> getEvents() {
        return getEvents(null);
    }

    /**
     * Build a select string from a query term.
     *
     * @param where the select string
     * @return the query string
     */
    protected String makeSelection(String where) {
        String queryString = "FROM Event event ";
        if (where != null && where.length() > 0) {
            queryString = queryString + " WHERE " + where;
        }
        return queryString;
    }

}


