package d1.persist.session;

import javax.naming.NamingException;
import javax.naming.Context;

/**
 * This class is a factory for application calendars, that binds using
 * JNDI registrations.
 *
 * This shows up a problem with JBoss 4.0.x, which doesnt have full Java EE 5 support.
 * In Java EE5 the binding would be automatic based on injection of attributes.
 * Instead of that, we have to to lookup of things.
 * To make life more entertaining, the JBoss documents lie about the names under
 * which things get stored.
 * @see <a href="http://docs.jboss.org/ejb3/app-server/tutorial/jndibinding/jndi.html">
 * JNDI binding tutorial</a>
 * @see <a href="http://docs.jboss.org/ejb3/app-server/tutorial/ear/ear.html">EAR
 * configuration tutorial</a>
 *
 */
public class JBoss4CalendarFactory implements CalendarFactory {

    private String jndiPath;

    /**
     * Bind to a JNDI path
     * @param jndiPath the path under JNDI to look for the session factory
     */
    public JBoss4CalendarFactory(String jndiPath) {
        this.jndiPath = jndiPath;
    }

    /**
     * Return a new or existing calendar session.
     *
     * @return a calendar session.
     */
    public CalendarSession getSession() {
        Context ctx=null;
        try {
            ctx = new javax.naming.InitialContext();
            CalendarSession calendar = (CalendarSession) ctx.lookup(jndiPath);
            return calendar;
        } catch (NamingException e) {
            throw new IllegalStateException(e);
        } finally {
            if (ctx!=null) {
                try {
                    ctx.close();
                } catch (NamingException e) {
                    //ignore close problems
                }
            }
        }
    }

    /**
     * Close the factory. Called at the end of life of the system, though this
     * cannot be guaranteed.
     */
    public void closeFactory() {

    }

    /**
     * Get the likely cause of failure.
     * @return details to include in error messages.
     */
    public String getLikelyCauseOfFailure() {
        return "Cannot resolve "+jndiPath;
    }


    /**
     * Returns a string representation of the object.
     *
     * @return a string representation of the object.
     */
    public String toString() {
        return getClass().getSimpleName()+" looking up "+jndiPath;
    }

}
