package d1.persist.session;

/**
 * a holder class for an unconfigured factory. This is what is used in the
 * session factory by default
 */
public class UnconfiguredFactory implements CalendarFactory {


	/**
	 * The text that warns we have no factory 
	 * {@value}
	 */
    private static final String NO_FACTORY =
        "Application is not configured -No Calendar Factory";


    /**
     * Return a new or existing calendar session.
     *
     * @return a calendar session.
     */
    public CalendarSession getSession() {
        throw new IllegalStateException(
            NO_FACTORY);
    }

    /**
     * Close the factory.  A no-op
     */
    public void closeFactory() {

    }

    /**
     * Get the likely cause of failure.
     *
     * @return {@link #NO_FACTORY}
     */
    public String getLikelyCauseOfFailure() {
        return NO_FACTORY;
    }


    /**
     * Returns a string representation of the object.
     * @return {@link #NO_FACTORY}
     */
    public String toString() {
        return NO_FACTORY;
    }
}
