package d1.persist.test;

import d1.persist.Event;
import d1.persist.PersistTools;

import javax.persistence.EntityTransaction;
import javax.persistence.Query;
import java.util.List;

/**
 */
public class EntityManagerTest extends Ejb3TestBase {

    public EntityManagerTest(String s) {
        super(s);
    }

    public void testPersist() throws Exception {
        createAndSaveEvent();
    }


    /**
     * Tests that updating our event (and flushing it) increases the version
     *
     * @throws Exception
     */
    public void testVersionIncrements() throws Exception {
        Event event = createAndSaveEvent();
        int version = event.getVersion();
        event.setText("updated");
        EntityTransaction transaction = null;
        try {
            transaction = manager.getTransaction();
            transaction.begin();
            Event e2 = manager.merge(event);
            transaction.commit();
            assertFalse("Versions are the same at "+version,
                    version == e2.getVersion());
        } catch (Exception e) {
            PersistTools.rollback(transaction);
            throw e;
        }
    }


    public void testPersistAndRetrieve() throws Exception {
        Event event = createTestEvent();
        manager.persist(event);
        manager.flush();
        String key = event.getKey();
        Event loaded = manager.find(Event.class, key);
        assertEquals(event, loaded);
    }


    public void testPersistAndRetrieve2() throws Exception {

        Event event = createAndSaveEvent();
        assertInDatabase(event);
    }

    private void assertInDatabase(Event event) {
        String key = event.getKey();
        Event loaded = manager.find(Event.class, key);
        assertEquals(event, loaded);
    }

    public void testTransactedPersistAndRetrieve() throws Exception {
        Event event = createTestEvent();
        EntityTransaction transaction = null;
        try {
            transaction = manager.getTransaction();
            transaction.begin();
            manager.persist(event);
            transaction.commit();
        } catch (Exception e) {
            if(transaction !=null && transaction.isActive()) {
                transaction.rollback();
            }
            throw e;
        }
        String key = event.getKey();
        Event loaded = manager.find(Event.class, key);
        assertEquals(event, loaded);
    }
    
    public void testQuery() throws Exception {
        Event event = createAndSaveEvent();
        Query query = manager.createQuery(
                "select e from Event e where e.key = :key");
        query.setParameter("key", event.getKey());
        List result = query.getResultList();
        assertNotNull(result);
        assertEquals("expected only 1 item in query result",
                1, result.size());
        Event e2 = (Event) result.get(0);
        assertEquals(event, e2);
    }


    /**
     * Just make sure that an empty transaction is harmless
     * @throws Exception
     */
    public void testEmptyTx() throws Exception {
        EntityTransaction transaction = null;
        try {
            transaction = manager.getTransaction();
            transaction.begin();
            transaction.commit();
        } catch (Exception e) {
            PersistTools.rollback(transaction);
            throw e;
        }
    }


    /**
     * test that we can detach things and merge them in
     * @throws Exception
     */
    public void testDetachedObject() throws Exception {
        Event event = createAndSaveEvent();
        closeManager();
        //here the event is detached.
        //we change it outside an operation.
        String text = "modified";
        event.setText(text);
        openManager();
        EntityTransaction transaction;
        transaction = manager.getTransaction();
        transaction.begin();
        try {
            Event merged = manager.merge(event);
            assertEquals(event, merged);
        } finally {
            transaction.commit();
        }
        closeManager();
        openManager();
        Event loaded = manager.find(Event.class, event.getKey());
        assertEquals(text, loaded.getText());
        assertEquals(event, loaded);
    }    
}
