package d1.persist.test;

import d1.persist.Event;
import d1.persist.PersistTools;
import junit.framework.AssertionFailedError;

import javax.persistence.EntityTransaction;

/**
 * Tests that show what appear to be bugs/quirks with EJB3
 */
public class HibernateEjbBugsTest extends Ejb3TestBase {

    public HibernateEjbBugsTest(String s) {
        super(s);
    }

    /**
     * This test
     * @throws Exception
     */
    public void testPersistRequiresATransaction() throws Exception {
        try {
            Event event = createTestEvent();
            manager.persist(event);
            manager.flush();
        } catch (javax.persistence.TransactionRequiredException e) {
            fail("Hibernate thinks a Tx is always required to persist");
        }
    }


    public void testDeleteAndFindFailsWrong() throws Exception {

        Event event = createTestEvent();
        String key = event.getKey();
        EntityTransaction transaction = null;
        try {
            transaction = manager.getTransaction();
            transaction.begin();
            manager.persist(event);
            Event e2 = manager.find(Event.class, key);
            assertEquals(event, e2);
            manager.remove(e2);
            try {
                e2 = manager.find(Event.class, key);
                assertNull("The spec says that find should return null here", e2);
            } catch(AssertionFailedError e) {
                throw e;
            } catch (Exception e) {
                fail("This is not in the spec: "+e);
            }
        } finally {
            PersistTools.rollback(transaction);
        }
    }
}
