
package org.antbook.tasks.filesize;

import org.apache.tools.ant.Task;
import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.Project;
import org.apache.tools.ant.types.FileSet;
import org.apache.tools.ant.types.resources.FileResource;

import java.io.File;
import java.util.List;
import java.util.ArrayList;
import java.util.Iterator;

public class FilesetSizeTask extends Task {

    private String property;
    private List<FileSet> filesets = new ArrayList<FileSet>();

    public void addFileset(FileSet fileset) {
        filesets.add(fileset);
    }

    public void setProperty(String property) {
        this.property = property;
    }

    public void setFile(File file) {
        if (!file.exists()) {
            throw new BuildException("Not found: " + file);
        }        
        FileSet fileset=new FileSet();
        fileset.setProject(getProject());
        fileset.setFile(file);
        addFileset(fileset);
    }

    public void execute() throws BuildException {
        if(property==null) {
            throw new BuildException("No property");
        }
        if(filesets.isEmpty()) {
            throw new BuildException("No files provided");
        }
        long size=0;
        int count=0;
        for(FileSet fileset:filesets) {
            Iterator it=fileset.iterator();
            while (it.hasNext()) {
                count++;
                FileResource resource = (FileResource) it.next();
                log(resource.getName(),Project.MSG_VERBOSE);
                File file = resource.getFile();
                size += file.length();
            }
        }
        if(count==0) {
            log("No files sized up", Project.MSG_WARN);
        }
        getProject().setNewProperty(property,
                        Long.toString(size));
    }
}
