package org.antbook.tasks.filesize;

import org.apache.tools.ant.Task;
import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.Project;
import org.apache.tools.ant.types.ResourceCollection;
import org.apache.tools.ant.types.Resource;
import org.apache.tools.ant.types.FileSet;
import org.apache.tools.ant.types.resources.Union;
import org.apache.tools.ant.types.resources.FileResource;
import java.util.Iterator;
import java.io.File;

public class ResourceSizeTask extends Task {
    private String property;
    private Union resources = new Union();

    public void setProperty(String property) {
        this.property = property;
    }

    public void add(ResourceCollection rc) {
        resources.add(rc);
    }

    public void setFile(File file) {
        if (!file.exists()) {
            throw new BuildException("Not found: " + file);
        }
        FileSet fileset = new FileSet();
        fileset.setProject(getProject());
        fileset.setFile(file);
        add(fileset);
    }

    public void execute() throws BuildException {
        if (property == null) {
            throw new BuildException("No property");
        }
        long size = 0;
        int count = 0;
        Iterator element = resources.iterator();
        while (element.hasNext()) {
            Resource resource = (Resource) element.next();
            if (!(resource instanceof FileResource)) {
                throw new BuildException("Not a file: " + resource);
            }
            log(resource.getName(), Project.MSG_VERBOSE);
            FileResource fileResource = (FileResource) resource;
            File file = fileResource.getFile();
            if (!file.exists()) {
                throw new BuildException("Not found: " + file);
            }
            size += file.length();
            count++;
        }
        if (count == 0) {
            log("No files sized up", Project.MSG_WARN);
        }
        getProject().setNewProperty(property, Long.toString(size));
    }
}
