package org.antbook.tasks;

import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.Project;
import org.apache.tools.ant.Task;
import org.apache.tools.ant.AntClassLoader;
import org.apache.tools.ant.types.Path;
import org.apache.tools.ant.types.Reference;

/**
 * task that loads a named class There is actually {@link
 * org.apache.tools.ant.util.ClasspathUtils.Delegate} that implements much of
 * this. This is just pulled out here because its easier that way
 */
public class LoadClassTask extends Task {
    private String name;
    private Path classpath;
    private String loaderRef;


    /** create the classpath now that we have a project */
    public void init() throws BuildException {
        classpath = new Path(getProject());
    }

    public void setName(String name) {
        this.name = name;
    }

    /**
     * Set the attribute
     *
     * @param classpath
     */
    public void setClasspath(Path classpath) {
        this.classpath = classpath;
    }

    /**
     * create a new classpath element
     *
     * @return
     */
    public Path createClasspath() {
        return classpath.createPath();
    }

    /**
     * Set a reference.
     *
     * @param classpathRef
     */
    public void setClasspathRef(Reference classpathRef) {
        createClasspath().setRefid(classpathRef);
    }


    /**
     * Load the class 
     */
    public void execute() {
        String message = "class " + name + " from '" + classpath + "'";
        log("loading "+message,Project.MSG_VERBOSE);
        AntClassLoader acl=new AntClassLoader(getProject(), classpath);
        try {
            Class clazz = Class.forName(name, false, acl);
        } catch (ClassNotFoundException e) {
            throw new BuildException("Failed to load "+message,e);
        } catch (LinkageError e) {
            throw new BuildException(
                    "Linkage Error loading "+message,e);
        } finally {
            //clean up any open files on the classpath
            acl.cleanup();
        }

    }
}
