package org.antbook;

import org.apache.tools.ant.filters.BaseFilterReader;
import org.apache.tools.ant.filters.ChainableReader;

import java.io.Reader;
import java.io.IOException;

public class EscapeFilter extends BaseFilterReader
    implements ChainableReader {

    private String queuedData = null;

    public EscapeFilter(final Reader in) {
        super(in);
    }

    public Reader chain(Reader rdr) {
        EscapeFilter newFilter = new EscapeFilter(rdr);
        newFilter.setProject(getProject());
        return newFilter;
    }

    public int read() throws IOException {
        if (queuedData != null && queuedData.length() == 0) {
            queuedData = null;
        }

        int ch = -1;
        if (queuedData != null) {
            ch = queuedData.charAt(0);
            queuedData = queuedData.substring(1);
            if (queuedData.length() == 0) {
                queuedData = null;
            }
        } else {
            ch = in.read();
            if (ch == -1) {
                return ch;
            }
            queuedData = getEscapeString(ch);
            if (queuedData != null) {
                return read();
            }
        }
        return ch;
    }

    private String getEscapeString(int ch) {
        String output = null;

        switch (ch) {
            case '<' : output = "&lt;"; break;
            case '>' : output = "&gt;"; break;
            case '"' : output = "&quot"; break;
            case '\'' : output = "&apos;"; break;
        }

        if (output != null) {
            return output;
        }

        if (ch < 32 || ch > 127) {
            return "&#x" + Integer.toHexString(ch) + ";";
        }

        return null;
    }

}
