package org.antbook.listeners;

import org.apache.tools.ant.DefaultLogger;
import org.apache.tools.ant.BuildEvent;
import org.apache.tools.ant.Project;

/**
 * generate a custom logger with personal messages extracted from the
 * project's own properties
 */
public class PersonalLogger extends DefaultLogger {

    /** Success property name: {@value} */
    private static final String SUCCESS = "ant.build.success";
    /** Failure property name:{@value} */
    private static final String FAILURE = "ant.build.failure";
    /** result text */
    private String result;

    @Override
    public void buildFinished(BuildEvent event) {
        String name;
        name = event.getException() == null ?
                                 SUCCESS
                                : FAILURE;
        Project p = event.getProject();
        result = p.replaceProperties("${" + name + '}');
        super.buildFinished(event);
    }

    /** @return The "BUILD FAILED" message */
    @Override
    protected String getBuildFailedMessage() {
        return result;
    }

    /** @return The "BUILD SUCCESSFUL" message */
    @Override
    protected String getBuildSuccessfulMessage() {
        return result;
    }

}
