package org.antbook.resources;

import org.apache.tools.ant.types.Resource;
import org.apache.tools.ant.BuildException;

import java.io.InputStream;
import java.io.IOException;
import java.security.SecureRandom;
import java.security.NoSuchAlgorithmException;

/**
 * a resource that generates a random stream of bytes
 */
public class RandomResource extends Resource 
    implements Cloneable {

    public RandomResource() {
//        super("random");
    }

    private Long seed;

    private String algorithm;

    public void setSeed(Long seed) {
        checkAttributesAllowed();
        this.seed = seed;
    }

    public void setAlgorithm(String algorithm) {
        checkAttributesAllowed();
        this.algorithm = algorithm;
    }

    public boolean isExists() {
        return true;
    }

    public long getLastModified() {
        return UNKNOWN_DATETIME;
    }

    public InputStream getInputStream() throws IOException {
        if(isReference()) {
            RandomResource that = (RandomResource) getCheckedRef();
            return that.getInputStream();
        } else {
           return new RandomInputStream(create(),getSize());
        }
    }

    private SecureRandom create() {
        SecureRandom generator;
        if(algorithm==null) {
            generator = new SecureRandom();
        } else {
            try {
                generator = SecureRandom.getInstance(algorithm);
            } catch (NoSuchAlgorithmException e) {
                throw new BuildException("unsupported algorithm "
                    +algorithm,
                    e);
            }
        }
        if(seed!=null) {
            generator.setSeed(seed.longValue());
        }
        return generator;
    }

}
