package org.antbook.resources;

import org.apache.tools.ant.types.Resource;
import org.apache.tools.ant.BuildException;

import java.io.InputStream;
import java.io.IOException;
import java.security.SecureRandom;
import java.security.NoSuchAlgorithmException;

/**
 * a resource that generates a random stream of bytes
 */
public class RandomResourceMinMax extends Resource
    implements Cloneable {

    private Long seed;

    private String algorithm;
    private int min=0;
    private int max=256;

    public RandomResourceMinMax() {
        super("random");
    }
    public void setSeed(Long seed) {
        checkAttributesAllowed();
        this.seed = seed;
    }

    public void setAlgorithm(String algorithm) {
        checkAttributesAllowed();
        this.algorithm = algorithm;
    }

    public void setMin(int min) {
        checkAttributesAllowed();
        this.min = min;
    }

    public void setMax(int max) {
        checkAttributesAllowed();
        this.max = max;
    }

    public void setMinChar(char minchar) {
        checkAttributesAllowed();
        this.min = minchar;
    }

    public void setMaxChar(char maxchar) {
        checkAttributesAllowed();
        this.max = maxchar;
    }

    public boolean isExists() {
        return true;
    }

    public long getLastModified() {
        return UNKNOWN_DATETIME;
    }

    public InputStream getInputStream() throws IOException {
        if(min>=max) {
            throw new BuildException("min "
                +min
                +"is greater than or equal to max "
                +max+")");
        }
        return new RandomInputStreamMinMax(create(),
                        getSize(),
                        min,
                        max);
    }

    private SecureRandom create() {
        SecureRandom generator;
        if(algorithm==null) {
            generator = new SecureRandom();
        } else {
            try {
                generator = SecureRandom.getInstance(algorithm);
            } catch (NoSuchAlgorithmException e) {
                throw new BuildException("unsupported algorithm "
                    +algorithm,
                    e);
            }
        }
        if(seed!=null) {
            generator.setSeed(seed.longValue());
        }
        return generator;
    }

}
